## Summary

<!-- What does this PR do? Link the related issue (e.g., Fixes #42). -->

## Changes

<!-- Bullet list of what changed and why. -->

-

## Checklist

- [ ] Tests pass (`pixi run test`)
- [ ] Linting passes (`pixi run lint`)
- [ ] JS bundle rebuilt if renderer changed (`pixi run build`)
- [ ] Documentation updated if applicable
